SystemOrganization addCategory: #PolymorphSystemSettings!

Object subclass: #PSMCSystemSettings
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'PolymorphSystemSettings'!

!PSMCSystemSettings class methodsFor: 'settings' stamp: 'AlainPlantec 1/10/2010 22:04'!
defaultMonticelloDiffToolsSettingOn: aBuilder
	<systemsettings>  
	(aBuilder setting: #polymorphDiffToolsUsedByDefault)
		label: 'Use Polymorph difference tools' translated;
		description: 'When enabled the Polymorph diff tools will be used with Monticello. When disabled, the original tools are used.' translated;
		parent: #monticello;
		target: PSMCPatchMorph;
		selector: #usedByDefault! !

Object subclass: #PolymorphSystemSettings
	instanceVariableNames: ''
	classVariableNames: 'DesktopColor DesktopGradientDirection DesktopGradientFillColor DesktopGradientOrigin DesktopImageFileName UseDesktopGradientFill'
	poolDictionaries: ''
	category: 'PolymorphSystemSettings'!

!PolymorphSystemSettings class methodsFor: 'settings' stamp: 'AlainPlantec 1/10/2010 09:31'!
appearanceSettingsOn: aBuilder 
	<systemsettings>
	(aBuilder group: #appearance)
		label: 'Appearance' translated; 
		description: 'All settings concerned with the look''n feel of your system' translated;
		noOrdering;
		with: [
			self morphicAppearanceSettingsOn: aBuilder.
			self desktopColorSettingsOn: aBuilder.
			self soundSettingsOn: aBuilder]! !

!PolymorphSystemSettings class methodsFor: 'desktop' stamp: 'AlainPlantec 12/1/2009 20:46'!
desktopBackgroundChanged
	| fill |
	self desktopImageFileName
		ifNotEmpty: [^ [Form setBackgroundFromImageFileNamed: self desktopImageFileName]
				on: Error
				do: []].
	self useDesktopGradientFill
		ifTrue: [World fillStyle isGradientFill
				ifTrue: [fill := World fillStyle]
				ifFalse: [fill := GradientFillStyle new].
			fill colorRamp: {0.0 -> self desktopColor darker. 1.0 -> self desktopGradientFillColor lighter}.
			fill origin: (World perform: self desktopGradientOrigin).
			self desktopGradientDirection = #Vertical
				ifTrue: [fill radial: false.
					fill normal: World width @ 0.
					fill direction: 0 @ World height].
			self desktopGradientDirection = #Horizontal
				ifTrue: [fill radial: false.
					fill normal: 0 @ World height.
					fill direction: World width @ 0]. 
			self desktopGradientDirection = #Radial
				ifTrue: [
					fill radial: true.
					self desktopGradientOrigin = #center
						ifTrue: [fill direction: World width // 2 @ 0.
							fill normal: 0 @ (World height // 2)]
						ifFalse: [fill direction: World width @ 0.
							fill normal: 0 @ World height]].
			World fillStyle: fill]
		ifFalse: [World color: self desktopColor].
		World changed! !

!PolymorphSystemSettings class methodsFor: 'desktop' stamp: 'AlainPlantec 1/10/2010 09:37'!
desktopColor
	^ DesktopColor ifNil: [DesktopColor := World defaultWorldColor] ! !

!PolymorphSystemSettings class methodsFor: 'desktop' stamp: 'AlainPlantec 11/28/2009 15:50'!
desktopColor: aColor
	DesktopColor := aColor.
	self desktopBackgroundChanged! !

!PolymorphSystemSettings class methodsFor: 'desktop' stamp: 'AlainPlantec 1/10/2010 09:31'!
desktopColorSettingsOn: aBuilder 
	(aBuilder group: #desktopSettings)
		label: 'Desktop';
		target: self;
		noOrdering;
		with: [
			(aBuilder setting: #desktopColor)
				label: 'Color';
				description: 'This is the only color of your desktop if no gradient is used. If you make use of a gradient, then this color is the first one of the gradient' translated;
				with: [
					(aBuilder setting: #useDesktopGradientFill)
						label: 'Gradient';
						description: 'If true, then more settings will be available in order to define the desktop background color gradient';
						noOrdering;
						with: [
							(aBuilder setting: #desktopGradientFillColor)
								label: 'Other color';
								description: 'This is the second color of your gradient (the first one is given by the "Color" setting' translated.
							(aBuilder pickOne: #desktopGradientDirection)
								label: 'Direction';
								domainValues: {#Horizontal. #Vertical. #Radial}.
							(aBuilder pickOne: #desktopGradientOrigin)
								label: 'Origin';
								domainValues: {
									'Top left' translated -> #topLeft. 
									'Top' translated -> #topCenter. 
									'Top right' translated -> #topRight. 
									'Right' translated -> #rightCenter.
									'Bottom right' translated ->  #bottomRight.
									'Bottom' translated -> #bottomCenter.
									'Bottom left' translated -> #bottomLeft.
									'Left' translated -> #leftCenter.
									'Center' translated -> #center}]].
			(aBuilder setting: #desktopImageFileName)
				type: #FilePath;
				description: 'The path of an png file which will be imported as a form and displayed as your desktop background' translated;
				label: 'Image file name']
						! !

!PolymorphSystemSettings class methodsFor: 'desktop' stamp: 'AlainPlantec 11/30/2009 06:33'!
desktopGradientDirection
	"#Radial #Vertical or #Horizontal"
	^ DesktopGradientDirection ifNil: [DesktopGradientDirection := #Vertical]! !

!PolymorphSystemSettings class methodsFor: 'desktop' stamp: 'AlainPlantec 11/28/2009 15:50'!
desktopGradientDirection: aSymbol
	"#Radial #Vertical or #Horizontal"
	DesktopGradientDirection := aSymbol.
	self desktopBackgroundChanged
! !

!PolymorphSystemSettings class methodsFor: 'desktop' stamp: 'AlainPlantec 11/30/2009 06:32'!
desktopGradientFillColor
	^ DesktopGradientFillColor ifNil: [DesktopGradientFillColor := self desktopColor]! !

!PolymorphSystemSettings class methodsFor: 'desktop' stamp: 'AlainPlantec 11/28/2009 15:50'!
desktopGradientFillColor: aColor 
	DesktopGradientFillColor := aColor.
	self desktopBackgroundChanged! !

!PolymorphSystemSettings class methodsFor: 'desktop' stamp: 'AlainPlantec 11/30/2009 06:37'!
desktopGradientOrigin
	"#topLeft #topCenter #topRight #rightCenter #bottomRight #bottomCenter #bottomLeft #leftCenter #center"
	^ DesktopGradientOrigin ifNil: [DesktopGradientOrigin := #topLeft]! !

!PolymorphSystemSettings class methodsFor: 'desktop' stamp: 'AlainPlantec 11/28/2009 16:10'!
desktopGradientOrigin: aSymbol
	"#Radial #Vertical or #Horizontal"
	DesktopGradientOrigin := aSymbol.
	self desktopBackgroundChanged
! !

!PolymorphSystemSettings class methodsFor: 'desktop' stamp: 'AlainPlantec 11/28/2009 12:00'!
desktopImageFileName
	^ DesktopImageFileName ifNil: [DesktopImageFileName := '']! !

!PolymorphSystemSettings class methodsFor: 'desktop' stamp: 'AlainPlantec 11/28/2009 15:47'!
desktopImageFileName: aFileName
	DesktopImageFileName := aFileName.
	self desktopBackgroundChanged! !

!PolymorphSystemSettings class methodsFor: 'morphic' stamp: 'AlainPlantec 1/10/2010 09:29'!
morphicAnimationSettingsOn: aBuilder 
	(aBuilder setting: #useAnimation)
		label: 'Animation' translated;
		target: UITheme;
		targetSelector: #currentAnimationSettings;
		description: 'If true, some animations will be use when opening and closing windows' translated;
		noOrdering;
		with: [
			(aBuilder setting: #animateClosing)
				label: 'Animate closing' translated;
				description: 'If true, then windows closing is animated' translated.
			(aBuilder range: #animationDelay) 
				label: 'Delay' translated;
				description: 'The delay between each step of the window animation in milliseconds.' translated;
				selector: #delay;
				range: (0 to: 30).
			(aBuilder range: #animationNumberOfSteps) 
				label: 'Number of steps' translated;
				description: 'The number of steps in the window animation.' translated;
				selector: #numberOfSteps;
				range: (0 to: 100).
		]! !

!PolymorphSystemSettings class methodsFor: 'morphic' stamp: 'AlainPlantec 1/10/2010 09:31'!
morphicAppearanceSettingsOn: aBuilder 
	(aBuilder group: #morphic)
		label: 'Morphic' translated;
		description: 'All morphic settings' translated;
		noOrdering;
		with: [
			(aBuilder pickOne: #uiThemeClass)
				label: 'User interface theme' translated;
				target: self;
				order: 1;
				domainValues: self uiThemeClassChoices.
			self morphicWindowsSettingsOn: aBuilder.
			self morphicMenuSettingsOn: aBuilder.
			self morphicHaloSettingsOn: aBuilder.
			self morphicAnimationSettingsOn: aBuilder.
			(aBuilder setting: #keyboardFocusOnMouseDown)
				label: 'Keyboard focus on mouse down' translated;
				target: MorphicModel;
				description: 'When enabled the mouse button must be clicked within a morph for it to take the keyboard focus.' translated.
			(aBuilder setting: #mouseOverForKeyboardFocus)
				label: 'Lose keyboard focus when mouse leave' translated;
				target: MorphicModel;
				description: 'When true, the mouse must be over a text or list pane in morphic for keystrokes to be felt, and when the mouse is out over the desktop, the so-called desktop-command-keys, such as cmd-b and cmd-R, are honored.  When false, list panes and text panes in morphic remain sensitive to keystrokes even after the mouse is no longer over the pane.' translated.
			(aBuilder setting: #showTextEditingState)
				label: 'Show text editing state' translated;
				target: PluggableTextMorph;
				description: 'When enabled the editing state of PluggableTextMorphs is shown as a colored inset border.' translated.
			(aBuilder setting: #balloonHelpEnabled)
				label: 'Balloon help'; 
				target: UITheme;
				targetSelector: #currentSettings.
			(aBuilder setting: #editableStringMorph)
				label: 'String morphs are editable' translated;
				target: StringMorph;
				description: 'If true, editing on StringMorph is possible if the shift key is pressed while selecting the morphs.' translated.
			(aBuilder setting: #defaultYellowButtonMenuEnabled)
				label: 'Show default yellow button menu' translated;
				target: Morph;
				description: 'If true, populate a yellow-button menu (default context menu).' translated.
			(aBuilder setting: #useUndo)
				label: 'Allow command undo' translated;
				target: CommandHistory;
				description: 'If true, morphic command undo will be generally available. This option has nothing to do with text editing undo.' translated;
				with: [
					(aBuilder setting: #infiniteUndo)
						label: 'Multiple undo' translated;
						description: 'Allow multiple undo.' translated.
					(aBuilder setting: #purgeUndoOnQuit)
						label: 'Purge on quit' translated;
						description: 'If true, all kept commands will be erased on quit' translated ]]
! !

!PolymorphSystemSettings class methodsFor: 'morphic' stamp: 'AlainPlantec 1/10/2010 09:30'!
morphicHaloSettingsOn: aBuilder 
	(aBuilder group: #halo)
		label: 'Halo' translated;
		parent: #morphic;
		description: 'All halo settings' translated;
		noOrdering;
		with: [
			(aBuilder setting: #haloEnclosesFullBounds)
				label: 'Encloses fullbounds' translated;
				target: HaloMorph;
				description: 'If true, halos will enclose the full bounds of the target Morph, rather than just the bounds' translated.
			(aBuilder setting: #showBoundsInHalo)
				label: 'Exhibits bounds' translated;
				target: HaloMorph;
				description: 'If true, halos will include a fine rectangle around the bounds of the target morph.' translated
		]! !

!PolymorphSystemSettings class methodsFor: 'morphic' stamp: 'AlainPlantec 1/10/2010 09:30'!
morphicMenuSettingsOn: aBuilder 
	(aBuilder group: #menu)
		label: 'Menu' translated;
		parent: #morphic;
		description: 'All menu settings' translated;
		target: UITheme;
		targetSelector: #currentSettings;
		noOrdering;
		with: [
			(aBuilder setting: #preferGradientFill)
				label: 'Gradient filling' translated;
				description: 'If true, then menus will have a gradient look' translated.
			(aBuilder setting: #flatMenu)
				label: 'Flat appearance' translated;
				description: 'If true, then menu will without 3D like borders.' translated.
			(aBuilder setting: #autoMenuColor)
				label: 'Computed color' translated;
				description: 'If true, then the menu color will be computed from world dressing.' translated.
			(aBuilder setting: #menuWithIcons)
				label: 'Automatically added icons' translated;
				description: 'If true, then menu item will be decorated with automatically found icons.' translated.
		]! !

!PolymorphSystemSettings class methodsFor: 'morphic' stamp: 'AlainPlantec 1/10/2010 09:31'!
morphicWindowsSettingsOn: aBuilder 
	(aBuilder group: #windows)
		label: 'Windows' translated;
		description: 'All windows settings' translated;
		noOrdering;
		with: [
			(aBuilder setting: #preferRoundCorner)
				target: UITheme;
				targetSelector: #currentSettings;
				label: 'Rounded corners' translated;
				description: 'If true, then windows, menu and other popups will have their corners rounded.' translated.
			(aBuilder range: #fullScreenMargin) 
						target: SystemWindow;
						label: 'Full screen margin' translated;
						description: 'Specify the amount of space that is let around a windows when it''s opened fullscreen' translated;
						range: (-5 to: 100).
			(aBuilder setting: #fadedBackgroundWindows)
				target: UITheme;
				targetSelector: #currentSettings;
				label: 'Fade background windows' translated;
				description: 'If true then, background windows appear more "washed out" to distinguish from the active window' translated.
			(aBuilder setting: #fastDragging)
				target: UITheme;
				targetSelector: #currentSettings;
				label: 'Fast dragging' translated;
				description: 'If true, window drag will be done by dragging an outline of the window instead of the whole window. It is very convenient on a slow machine' translated]
			
			
			
! !

!PolymorphSystemSettings class methodsFor: 'sound' stamp: 'AlainPlantec 1/10/2010 07:55'!
soundSettingsOn: aBuilder
	(aBuilder setting: #soundEnabled)
		label: 'Sound'; 
		target: SoundSettings;
		noOrdering;
		with: [
			(aBuilder setting: #useThemeSounds)
				label: 'Use theme sounds';
				with: [
					(aBuilder pickOne: #soundThemeClass)
						label: 'Sound theme' translated;
						target: self;
						domainValuesGetter: (MessageSend receiver: self selector: #soundThemeClassChoices).
				]]! !

!PolymorphSystemSettings class methodsFor: 'sound' stamp: 'AlainPlantec 1/10/2010 07:54'!
soundThemeClass
	^ SoundTheme current class
! !

!PolymorphSystemSettings class methodsFor: 'sound' stamp: 'AlainPlantec 1/10/2010 07:54'!
soundThemeClass: aSoundThemeClass
	aSoundThemeClass ifNil: [^ self].
	self soundThemeClass ~= aSoundThemeClass
		ifTrue: [aSoundThemeClass beCurrent]! !

!PolymorphSystemSettings class methodsFor: 'sound' stamp: 'AlainPlantec 1/10/2010 07:54'!
soundThemeClassChoices
	^ SoundTheme allThemeClasses collect: [:c | c themeName -> c]! !

!PolymorphSystemSettings class methodsFor: 'morphic' stamp: 'AlainPlantec 12/10/2009 16:04'!
uiThemeClass
	^ UITheme current class
! !

!PolymorphSystemSettings class methodsFor: 'morphic' stamp: 'AlainPlantec 12/18/2009 11:20'!
uiThemeClass: aUIThemeClass
	| themeClass |
	themeClass := aUIThemeClass ifNil: [Smalltalk at: #UIThemeWatery2 ifAbsent: [UITheme allSubclasses anyOne]].
	self uiThemeClass ~= themeClass
		ifTrue: [themeClass beCurrent]! !

!PolymorphSystemSettings class methodsFor: 'morphic' stamp: 'AlainPlantec 12/10/2009 16:02'!
uiThemeClassChoices
	^ UITheme allThemeClasses collect: [:c | c themeName -> c]! !

!PolymorphSystemSettings class methodsFor: 'desktop' stamp: 'AlainPlantec 11/30/2009 06:31'!
useDesktopGradientFill
	^ UseDesktopGradientFill ifNil: [UseDesktopGradientFill := false]! !

!PolymorphSystemSettings class methodsFor: 'desktop' stamp: 'AlainPlantec 11/28/2009 15:49'!
useDesktopGradientFill: aBoolean 
	UseDesktopGradientFill := aBoolean.
	self desktopBackgroundChanged! !

Object subclass: #TaskListSystemSettings
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'PolymorphSystemSettings'!

!TaskListSystemSettings class methodsFor: 'settings' stamp: 'AlainPlantec 12/15/2009 10:07'!
taskListSettingOn: aBuilder
	<systemsettings> 
	(aBuilder setting: #keepTaskListOpen)
		label: 'Keep task list open' translated;
		description: 'Whether the tasklist is closed (and the selected window activated) when the command key is released' translated;
		parent: #morphic;
		selector: #keepOpen;
		target: TasklistMorph! !

Object subclass: #TaskbarSystemSettings
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'PolymorphSystemSettings'!

!TaskbarSystemSettings class methodsFor: 'settings' stamp: 'AlainPlantec 12/15/2009 10:04'!
taskbarSettingOn: aBuilder
	<systemsettings>
	(aBuilder setting: #showTaskbar)
		target: TaskbarMorph;
		parent: #morphic;
		label: 'Taskbar' translated;
		description: 'Whether the world''s taskbar should be shown or not.' translated;
		with: [
			(aBuilder setting: #showWindowPreview)
				label: 'Window preview' translated;
				description: 'Whether the world''s taskbar buttons should show previews of the associated window while the mouse is over them.' translated
		]! !
